# rds-snapshot
rds-snapshot is a tool for creating and managing RDS snapshots from the command line or scripts.

## Features

*   List, create and delete snapshots
*   Cleanup snapshots older than a [x] days

## Installation

    pip install rds-snapshot

## Install requirements
*   boto3

## Commands
For a list of all commands and features run:

    rds-snapshot --help
    rds-snapshot [command] --help